==> mongodb-src-r3.0.5.tar.gz: mongodb-src-r3.0.5/src/mongo/dbtests/mock/mock_dbclient_cursor.cpp <==
//@file dbclientmockcursor.h

/*    Copyright 2012 10gen Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects
 *    for all of the code used other than as permitted herein. If you modify
 *    file(s) with this exception, you may extend this exception to your
 *    version of the file(s), but you are not obligated to do so. If you do not
 *    wish to do so, delete this exception statement from your version. If you
 *    delete this exception statement from all source files in the program,
 *    then also delete it in the license file.
 */

#include "mongo/dbtests/mock/mock_dbclient_cursor.h"

namespace mongo {
    MockDBClientCursor::MockDBClientCursor(mongo::DBClientBase* client,
            const mongo::BSONArray& resultSet):
        mongo::DBClientCursor(client, "", 0, 0, 0) {
        _resultSet = resultSet.copy();
        _cursor.reset(new mongo::DBClientMockCursor(BSONArray(_resultSet)));
    }

    bool MockDBClientCursor::more() {
        return _cursor->more();
    }

    mongo::BSONObj MockDBClientCursor::next() {
        return _cursor->next();
    }
}

==> mongodb-src-r3.2.17.tar.gz: mongodb-src-r3.2.17/src/mongo/dbtests/mock/mock_dbclient_cursor.cpp <==
//@file dbclientmockcursor.h

/*    Copyright 2012 10gen Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects
 *    for all of the code used other than as permitted herein. If you modify
 *    file(s) with this exception, you may extend this exception to your
 *    version of the file(s), but you are not obligated to do so. If you do not
 *    wish to do so, delete this exception statement from your version. If you
 *    delete this exception statement from all source files in the program,
 *    then also delete it in the license file.
 */

#include "mongo/dbtests/mock/mock_dbclient_cursor.h"

namespace mongo {
MockDBClientCursor::MockDBClientCursor(mongo::DBClientBase* client,
                                       const mongo::BSONArray& resultSet)
    : mongo::DBClientCursor(client, "", 0, 0, 0) {
    _resultSet = resultSet.copy();
    _cursor.reset(new mongo::DBClientMockCursor(BSONArray(_resultSet)));
}

bool MockDBClientCursor::more() {
    return _cursor->more();
}

mongo::BSONObj MockDBClientCursor::next() {
    return _cursor->next();
}
}
